@@ -127,12 +127,33 @@ func connect(dsn string) (*sql.DB, error) {
 
 func funcsMap() template.FuncMap {
 	return template.FuncMap{
-		"trim": func(s string, size int) string {
+		"trim": func(size int, s string) string {
 			if len(s) < size {
 				return s
 			}
-			return s[:size]
+			return s[:size]+"..."
 		},
+        "convertnullstring": func(s sql.NullString) string {
+            if s.Valid {
+                return s.String
+            } else {
+                return ""
+            }
+        },
+        "convertnullint64": func(s sql.NullInt64) int64 {
+            if s.Valid {
+                return s.Int64
+            } else {
+                return 0
+            }
+        },
+        "convertnullfloat64": func(s sql.NullFloat64) float64 {
+            if s.Valid {
+                return s.Float64
+            } else {
+                return 0.0
+            }
+        },
 	}
 }
 
